@@ -4,13 +4,17 @@ import tempfile
 
 from flask import make_response, request
 
+from slugify import slugify
+
 import ckan.model as model
 import ckan.plugins.toolkit as toolkit
 
 from ckan.logic import get_action, ValidationError
+from ckan.views.dataset import _tag_string_to_list
 
 from ckanext.datapackage_creator.utils import row_to_dict
 from ckanext.datapackage_creator.model import Datapackage, DatapackageResource
+from ckanext.datapackage_creator.validation import validate_resource
 
 
 def inference():
@@ -36,8 +40,8 @@ def inference():
         'filepath': tmp.name
     }
     result = action(context, data)
-    _, name = os.path.split(file.filename)
-    result['metadata']['name'] = name
+    name, ext = os.path.splitext(file.filename)
+    result['metadata']['name'] = slugify(name)
     response.data = json.dumps(result)
     return response
 
@@ -56,8 +60,10 @@ def save_resource():
     except toolkit.NotAuthorized:
         toolkit.abort(401, toolkit._('Unauthorized to create a dataset'))
     data = request.form.copy()
+    data['state'] = 'active'
+    data['url_type'] = 'upload'
+    data['upload'] = request.files['upload']
     metadata = data['metadata']
-    package_id = data['package_id']
     del data['metadata']
     resource_id = data.get('id')
     data_response = {
@@ -65,6 +71,7 @@ def save_resource():
         'resource': None
     }
     try:
+        validate_resource(data)
         if resource_id:
             action = get_action('resource_update')
         else:
@@ -134,6 +141,8 @@ def save_package():
         toolkit.abort(401, toolkit._('Unauthorized to create a dataset'))
     data = request.form.copy()
     data['_ckan_phase'] = 'dataset_new_1'
+    tag_string = data.pop('tag_string')
+    data['tags'] = _tag_string_to_list(tag_string)
     package_id = data.get('id')
     if not package_id:
         data['state'] = 'draft'
@@ -141,9 +150,11 @@ def save_package():
     else:
         package_action = get_action('package_update')
     metadata = data.pop('metadata')
+    metadata_json = json.loads(metadata)
+    data['extras'] = metadata_json['extras']
     data_response = {
         'has_error': False,
-        'package': None
+        'package': None,
     }
     try:
         package = package_action(context, data)
@@ -183,9 +194,10 @@ def publish_package():
     }
     data = request.form.copy()
     data['state'] = 'active'
+    package = model.Session.query(model.Package).filter(model.Package.name==data['id']).one()
     try:
-        action = get_action('package_update')
-        action(context, data)
+        package.state = 'active'
+        model.Session.commit()
     except ValidationError as e:
         data_response['errors'] = e.error_dict
         data_response['error_summary'] = e.error_summary
@@ -216,7 +228,7 @@ def datapackage_show(package_id):
     }
     try:
         datapackage = get_action('datapackage_show')(context, data)
-    except:
+    except Exception as ex:
         datapackage = Datapackage()
     data = {
         'id': package_id
