@@ -14,13 +14,13 @@ var app = new Vue({
                 show: true,
                 fields: [],
                 name: '',
+                title: '',
                 description: '',
                 format: '',
                 type: '',
                 encoding: '',
                 show_fields: true,
                 inference: null,
-                resource: null,
                 current_field: [],
                 has_error: false,
                 error_summary: [],
@@ -86,7 +86,11 @@ var app = new Vue({
             },
             {
                 value: 'max_min',
-                name: 'Max / Min'
+                name: 'Maximum / Minimum'
+            },
+            {
+                value: 'length',
+                name: 'Maximum Length / Minimum Length'
             },
             {
                 value: 'list',
@@ -158,6 +162,7 @@ var app = new Vue({
             axios.post("/datapackage-creator/inference", formData, { headers })
                 .then((res) => {
                     resource.error_summary = []
+                    resource.has_error = false
                     resource.inference = res.data
                     resource.name = resource.inference.metadata.name
                     resource.encoding = resource.inference.metadata.encoding
@@ -170,15 +175,13 @@ var app = new Vue({
                     }
                 })
                 .catch(() => {
+                    resource.has_error = true
                     resource.error_summary = ['Unable to upload the file']
                 })
         },
         editMetadata(resource, field) {
             resource.current_field = field
             resource.show_fields = false
-            // let resourceModal = this.$refs[`modal_${resource.index}`]
-            // let modalInstance = new bootstrap.Modal(resourceModal)
-            // modalInstance.show()
         },
         getFormatOptions(type) {
             if(type === 'string') {
@@ -187,6 +190,49 @@ var app = new Vue({
                 return this.defaultFormatOptions
             }
         },
+        checkMetadata(field) {
+            const closeButton = this.$refs[`modal_close_${field.name}`][0]
+            let valid = true
+            field.extras.forEach(extra => {
+                if(extra.type == 'enum' || extra.type == 'list') {
+                    if(extra.value === '') {
+                        extra.list_error = true
+                        valid = false
+                    } else {
+                        extra.list_error = false
+                    }
+                } else if(extra.type == 'max_min') {
+                    if(!extra.min) {
+                        extra.min_error = true
+                        valid = false
+                    } else {
+                        extra.min_error = false
+                    }
+                    if(!extra.max) {
+                        extra.max_error = true
+                        valid = false
+                    } else {
+                        extra.max_error = false
+                    }
+                } else if(extra.type == 'length') {
+                    if(!extra.min_length) {
+                        extra.min_length_error = true
+                        valid = false
+                    } else {
+                        extra.min_length_error = false
+                    }
+                    if(!extra.max_length) {
+                        extra.max_length_error = true
+                        valid = false
+                    } else {
+                        extra.max_length_error = false
+                    }
+                }
+            })
+            if(valid) {
+                closeButton.click()
+            }
+        },
         saveMetadata(resource, field) {
             resource.current_field = null
             resource.show_fields = true
@@ -196,12 +242,14 @@ var app = new Vue({
             formData.append('upload', resource.file)
             const headers = { 'Content-Type': 'multipart/form-data' }
             formData.append('package_id', this.package_id)
+            formData.append('name', resource.name)
+            formData.append('title', resource.title)
             formData.append('description', resource.description)
             formData.append('format', resource.format)
             formData.append('encoding', resource.encoding)
             formData.append('type', resource.type)
             formData.append('id', resource.id)
-            formData.append('metadata', JSON.stringify(resource.fields))
+            formData.append('metadata', JSON.stringify(resource))
             axios.post("/datapackage-creator/save-resource", formData, { headers }).then((res) => {
                 resource.has_error = res.data.has_error
                 resource.errors = res.data.errors
@@ -227,6 +275,9 @@ var app = new Vue({
         },
         addResource() {
             this.resource_index += 1
+            this.resources.forEach(resource => {
+                resource.show = false
+            })
             this.resources.push(
                 {
                     id: '',
@@ -257,8 +308,19 @@ var app = new Vue({
                 type: '',
                 max: 0,
                 min: 0,
-                title: '',
-                value: ''
+                max_length: 0,
+                min_length: 0,
+                value: '',
+                min_error: false,
+                max_error: false,
+                min_length_error: false,
+                max_length_error: false,
+                list_error: false
+            })
+        },
+        deleteMetadata(field, extra) {
+            field.extras = field.extras.filter(function(value, index, arr){
+                return value.type != extra.type
             })
         },
         addResourceMetadadata(resource) {
